Mississippi Supreme Court

Court of Appeals Opinion Alphabetical Search Results 2014

Ace Pipe Cleaning, Inc. v. Hemphill Construction Company, Inc.
2012-CA-00550-COA | 2/28/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Adrian Williams v. State of Mississippi
2012-KA-01958-COA |  | Hand Down List
Roberts, Larry E.
Adrian Williams v. State of Mississippi
2012-KA-01958-COA |  | Hand Down List
Roberts, Larry E.
Albert Donelson v. State of Mississippi
2012-KA-00859-COA | 11/16/2011 | Hand Down List
Maxwell, James D., II
Albert Donelson v. State of Mississippi
2012-KA-00859-COA | 11/16/2011 | Hand Down List
Maxwell, James D., II
Albert Edmond v. State of Mississippi
2012-CP-00768-COA | 7/19/2012 | Hand Down List
Irving, Tyree
Albert Edmond v. State of Mississippi
2012-CP-00768-COA | 7/19/2012 | Hand Down List
Irving, Tyree
Albert L. Brisco, Jr. v. State of Mississippi
2013-KA-01117-COA | 4/12/2013 | Hand Down List
Lee, L. Joseph
Albert L. Brisco, Jr. v. State of Mississippi
2013-KA-01117-COA | 4/12/2013 | Hand Down List
Lee, L. Joseph
Albert Lewis Watts v. State of Mississippi
2012-KA-01838-COA | 9/4/2012 | Hand Down List
Fair, Eugene Love, Jr.
Albert Lewis Watts v. State of Mississippi
2012-KA-01838-COA | 9/4/2012 | Hand Down List
Fair, Eugene Love, Jr.
Alfred Stewart, Jr. v. State of Mississippi
2012-KA-01112-COA |  | Hand Down List
Carlton, Virginia Carter
Alfred Stewart, Jr. v. State of Mississippi
2012-KA-01112-COA |  | Hand Down List
Carlton, Virginia Carter
Alisha Vanwey v. State of Mississippi
2013-CP-00818-COA | 4/26/2013 | Hand Down List
Irving, Tyree
Alisha Vanwey v. State of Mississippi
2013-CP-00818-COA | 4/26/2013 | Hand Down List
Irving, Tyree
Amanda Cleveland v. Heritage Properties, Inc.
2013-WC-00451-COA | 2/21/2013 | Hand Down List
Maxwell, James D., II
Amanda Cleveland v. Heritage Properties, Inc.
2013-WC-00451-COA | 2/21/2013 | Hand Down List
Maxwell, James D., II
Andre Davis v. State of Mississippi
2013-CP-00986-COA | 5/20/2013 | Hand Down List
Fair, Eugene Love, Jr.
Andre Davis v. State of Mississippi
2013-CP-00986-COA | 5/20/2013 | Hand Down List
Fair, Eugene Love, Jr.
Andrew K. Matthies v. Red Mountain Entertainment, Inc.
2012-CA-00497-COA | 12/6/2012 | Hand Down List
Roberts, Larry E.
Andrew K. Matthies v. Red Mountain Entertainment, Inc.
2012-CA-00497-COA | 12/6/2012 | Hand Down List
Roberts, Larry E.
Anita White v. Charles Tommy White
2012-CT-01083-SCT | 11/23/2011 | Hand Down List
Roberts, Larry E.
Anita White v. Charles Tommy White
2012-CT-01083-SCT | 11/23/2011 | Hand Down List
Roberts, Larry E.
Anthony Donnell Williams v. State of Mississippi
2013-CT-00515-SCT | 6/30/2009 | Hand Down List
Carlton, Virginia Carter
Anthony Donnell Williams v. State of Mississippi
2013-CT-00515-SCT | 6/30/2009 | Hand Down List
Carlton, Virginia Carter
Anthony J. Newson v. Lori L. Newson
2013-CA-00275-COA | 10/23/2012 | Hand Down List
Carlton, Virginia Carter
Anthony J. Newson v. Lori L. Newson
2013-CA-00275-COA | 10/23/2012 | Hand Down List
Carlton, Virginia Carter
Anthony Laws v. Louisville Ladder, Inc.
2013-CA-00427-COA | 2/7/2013 | Hand Down List
Carlton, Virginia Carter
Anthony Laws v. Louisville Ladder, Inc.
2013-CA-00427-COA | 2/7/2013 | Hand Down List
Carlton, Virginia Carter
Antonio Williams v. State of Mississippi
2013-CP-00575-COA | 3/13/2013 | Hand Down List
Maxwell, James D., II
Antonio Williams v. State of Mississippi
2013-CP-00575-COA | 3/13/2013 | Hand Down List
Maxwell, James D., II
Arthur D. Davis v. Travis T. Vance
2013-CA-00033-COA | 11/28/2012 | Hand Down List
Maxwell, James D., II
Arthur D. Davis v. Travis T. Vance
2013-CA-00033-COA | 11/28/2012 | Hand Down List
Maxwell, James D., II
Arthur K. Collins v. Myra Helen Collins
2012-CA-01059-COA | 3/8/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Arthur K. Collins v. Myra Helen Collins
2012-CA-01059-COA | 3/8/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Arthur Thomas v. State of Mississippi
2013-CA-00371-COA | 2/19/2013 | Hand Down List
Fair, Eugene Love, Jr.
Arthur Thomas v. State of Mississippi
2013-CA-00371-COA | 2/19/2013 | Hand Down List
Fair, Eugene Love, Jr.
Arthur Woods v. State of Mississippi
2012-CP-00379-COA | 8/30/2011 | Hand Down List
Maxwell, James D., II
Arthur Woods v. State of Mississippi
2012-CP-00379-COA | 8/30/2011 | Hand Down List
Maxwell, James D., II
Aundrey Douglas Hill v. State of Mississippi
2012-CP-01386-COA | 8/10/2012 | Hand Down List
Maxwell, James D., II
Aundrey Douglas Hill v. State of Mississippi
2012-CP-01386-COA | 8/10/2012 | Hand Down List
Maxwell, James D., II
Bar-Til, Inc. v. Superior Asphalt
2013-CA-00304-COA | 9/5/2012 | Hand Down List
Carlton, Virginia Carter
Bar-Til, Inc. v. Superior Asphalt
2013-CA-00304-COA | 9/5/2012 | Hand Down List
Carlton, Virginia Carter
Barbara Ann Thompson Bolton v. Roger D. Weiner
2012-CA-01507-COA | 8/14/2012 | Hand Down List
Carlton, Virginia Carter
Barbara Ann Thompson Bolton v. Roger D. Weiner
2012-CA-01507-COA | 8/14/2012 | Hand Down List
Carlton, Virginia Carter
Barbara Sharlow v. Robert Raybourn
2012-CA-01373-COA | 4/16/2012 | Hand Down List
Barnes, Donna M.
Barbara Sharlow v. Robert Raybourn
2012-CA-01373-COA | 4/16/2012 | Hand Down List
Barnes, Donna M.
Bernard Hayes, III v. State of Mississippi
2013-KA-00376-COA | 2/6/2013 | Hand Down List
Barnes, Donna M.
Bernard Hayes, III v. State of Mississippi
2013-KA-00376-COA | 2/6/2013 | Hand Down List
Barnes, Donna M.
Bertha Mae Wilson v. State of Mississippi
2013-KA-00346-COA | 1/25/2013 | Hand Down List
Roberts, Larry E.
Bertha Mae Wilson v. State of Mississippi
2013-KA-00346-COA | 1/25/2013 | Hand Down List
Roberts, Larry E.
Beulah Abrams v. Republic Finance, LLC
2013-CA-01271-COA | 6/24/2013 | Hand Down List
Fair, Eugene Love, Jr.
Beulah Abrams v. Republic Finance, LLC
2013-CA-01271-COA | 6/24/2013 | Hand Down List
Fair, Eugene Love, Jr.
Beverly B. Evans v. Robert D. Evans
2012-CA-02026-COA | 11/9/2012 | Hand Down List
Lee, L. Joseph
Beverly B. Evans v. Robert D. Evans
2012-CA-02026-COA | 11/9/2012 | Hand Down List
Lee, L. Joseph
Billy J. Fields v. City of Clarksdale, Mississippi
2011-CA-01013-COA | 5/26/2011 | Hand Down List
Roberts, Larry E.
Billy J. Fields v. City of Clarksdale, Mississippi
2011-CA-01013-COA | 5/26/2011 | Hand Down List
Roberts, Larry E.
Bonnie Jones Dixon v. Annie Ruth Jones
2012-CA-01992-COA | 11/29/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Bonnie Jones Dixon v. Annie Ruth Jones
2012-CA-01992-COA | 11/29/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Brandon Celestine v. State of Mississippi
2013-CP-00348-COA | 1/23/2013 | Hand Down List
Ishee, David Michael
Brandon Celestine v. State of Mississippi
2013-CP-00348-COA | 1/23/2013 | Hand Down List
Ishee, David Michael
Brenda Jackson v. Mississippi Department of Employment Security
2012-CC-01590-COA | 3/12/2012 | Hand Down List
Barnes, Donna M.
Brenda Jackson v. Mississippi Department of Employment Security
2012-CC-01590-COA | 3/12/2012 | Hand Down List
Barnes, Donna M.
Brian Aldridge v. Clarke Aldridge
2012-CT-01301-SCT | 5/23/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Candice Fulgham v. AAA Cooper Transportation Company
2013-CA-00331-COA | 1/22/2013 | Hand Down List
Roberts, Larry E.
Candice Fulgham v. AAA Cooper Transportation Company
2013-CA-00331-COA | 1/22/2013 | Hand Down List
Roberts, Larry E.
Carl Anthony Houston, Jr. v. State of Mississippi
2013-KA-00246-COA | 1/25/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Carl Anthony Houston, Jr. v. State of Mississippi
2013-KA-00246-COA | 1/25/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Carl E. Sanders v. Gary Sanders
2012-CT-02035-COA |  | Hand Down List
James, Ceola
Carl E. Sanders v. Gary Sanders
2012-CT-02035-COA |  | Hand Down List
James, Ceola
Carl Ray Hale v. Mississippi State Licensed Professional Counselors
2012-SA-01618-COA | 9/13/2012 | Hand Down List
James, Ceola
Carl Ray Hale v. Mississippi State Licensed Professional Counselors
2012-SA-01618-COA | 9/13/2012 | Hand Down List
James, Ceola
Carol Lynn Ward v. Wilmer Keith Ward
2012-CA-01468-COA | 8/10/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Carol Lynn Ward v. Wilmer Keith Ward
2012-CA-01468-COA | 8/10/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Catina Turner v. Entergy Mississippi, Inc.
2012-CA-01286-COA | 7/23/2012 | Hand Down List
Ishee, David Michael
Catina Turner v. Entergy Mississippi, Inc.
2012-CA-01286-COA | 7/23/2012 | Hand Down List
Ishee, David Michael
Charles Bester v. State of Mississippi
2013-CP-00058-COA | 9/26/2012 | Hand Down List
Roberts, Larry E.
Charles Bester v. State of Mississippi
2013-CP-00058-COA | 9/26/2012 | Hand Down List
Roberts, Larry E.
Cherri R. Porter v. Max Mullins
2012-CA-01793-COA | 9/25/2012 | Hand Down List
Maxwell, James D., II
Cherri R. Porter v. Max Mullins
2012-CA-01793-COA | 9/25/2012 | Hand Down List
Maxwell, James D., II
Christopher Brown v. State of Mississippi
2012-KA-01348-COA | 7/17/2012 | Hand Down List
Carlton, Virginia Carter
Christopher Brown v. State of Mississippi
2012-KA-01348-COA | 7/17/2012 | Hand Down List
Carlton, Virginia Carter
Christopher Conway Boyd v. State of Mississippi
2013-CA-00681-COA | 3/18/2013 | Hand Down List
Barnes, Donna M.
Christopher Conway Boyd v. State of Mississippi
2013-CA-00681-COA | 3/18/2013 | Hand Down List
Barnes, Donna M.
Christopher Lee Baxter v. State of Mississippi
2012-KA-01032-COA | 5/15/2012 | Hand Down List
Irving, Tyree
Christopher Lee Baxter v. State of Mississippi
2012-KA-01032-COA | 5/15/2012 | Hand Down List
Irving, Tyree
Christopher Patrick Jordan v. State of Mississippi
2013-KA-00183-COA | 7/27/2012 | Hand Down List
Fair, Eugene Love, Jr.
Christopher Patrick Jordan v. State of Mississippi
2013-KA-00183-COA | 7/27/2012 | Hand Down List
Fair, Eugene Love, Jr.
Christopher Roberts v. Yolanda Roberts
2012-CA-01523-COA | 3/2/2012 | Hand Down List
James, Ceola
Christopher Roberts v. Yolanda Roberts
2012-CA-01523-COA | 3/2/2012 | Hand Down List
James, Ceola
Christopher S. Sobrado v. State of Mississippi
2012-CP-00484-COA | 4/9/2012 | Hand Down List
Roberts, Larry E.
City of Natchez, Mississippi v. Andre De La Barre
2012-CT-00984-COA | 6/1/2012 | Hand Down List
Irving, Tyree
City of Natchez, Mississippi v. Andre De La Barre
2012-CT-00984-COA | 6/1/2012 | Hand Down List
Irving, Tyree
Clarence Dwayne Jefferson v. State of Mississippi
2013-KA-00764-COA | 4/16/2013 | Hand Down List
Fair, Eugene Love, Jr.
Clarence Dwayne Jefferson v. State of Mississippi
2013-KA-00764-COA | 4/16/2013 | Hand Down List
Fair, Eugene Love, Jr.
Claude E. Pickett v. Michael T. Gallagher
2012-CP-01155-COA | 6/26/2012 | Hand Down List
Barnes, Donna M.
Claude E. Pickett v. Michael T. Gallagher
2012-CP-01155-COA | 6/26/2012 | Hand Down List
Barnes, Donna M.
Clement B. Saucier, Jr. v. Peoples Bank of Biloxi, Mississippi
2011-CA-01922-COA | 10/25/2011 | Hand Down List
Griffis, T. Kenneth, Jr.
Cleveland MHC, LLC v. City of Richland, Mississippi
2013-CA-00286-COA | 1/28/2013 | Hand Down List
Ishee, David Michael
Cleveland MHC, LLC v. City of Richland, Mississippi
2013-CA-00286-COA | 1/28/2013 | Hand Down List
Ishee, David Michael
Cliff Hensley v. State of Mississippi
2013-CA-00762-COA | 4/5/2013 | Hand Down List
Carlton, Virginia Carter
Cliff Hensley v. State of Mississippi
2013-CA-00762-COA | 4/5/2013 | Hand Down List
Carlton, Virginia Carter
Constance Jo Sims v. Stephen Sims
2013-CA-00885-COA | 3/21/2013 | Hand Down List
Fair, Eugene Love, Jr.
Constance Jo Sims v. Stephen Sims
2013-CA-00885-COA | 3/21/2013 | Hand Down List
Fair, Eugene Love, Jr.
Corderro Seales v. State of Mississippi
2013-KA-00162-COA | 11/9/2012 | Hand Down List
James, Ceola
Corderro Seales v. State of Mississippi
2013-KA-00162-COA | 11/9/2012 | Hand Down List
James, Ceola
Cortez D. Washington v. State of Mississippi
2012-KA-00700-COA | 4/9/2012 | Hand Down List
Roberts, Larry E.
Cortez D. Washington v. State of Mississippi
2012-KA-00700-COA | 4/9/2012 | Hand Down List
Roberts, Larry E.
Courtney Harmon v. Linda Randle Harmon
2013-CA-00166-COA | 12/21/2012 | Hand Down List
Maxwell, James D., II
Courtney Harmon v. Linda Randle Harmon
2013-CA-00166-COA | 12/21/2012 | Hand Down List
Maxwell, James D., II
Courtney Nevels v. Wal-Mart Transportation, LLC
2013-CA-01050-COA | 6/13/2013 | Hand Down List
Roberts, Larry E.
Courtney Nevels v. Wal-Mart Transportation, LLC
2013-CA-01050-COA | 6/13/2013 | Hand Down List
Roberts, Larry E.
Crown Communication, LLC v. T6 Unison Site Management, LLC
2012-CA-01510-COA | 8/6/2012 | Hand Down List
Barnes, Donna M.
Crown Communication, LLC v. T6 Unison Site Management, LLC
2012-CA-01510-COA | 8/6/2012 | Hand Down List
Barnes, Donna M.
Crystal Clay v. State of Mississippi
2013-KA-00980-COA | 6/3/2013 | Hand Down List
Lee, L. Joseph
Crystal Clay v. State of Mississippi
2013-KA-00980-COA | 6/3/2013 | Hand Down List
Lee, L. Joseph
Currie Glenn Davis v. State of Mississippi
2013-KM-00167-COA |  | Hand Down List
Maxwell, James D., II
Currie Glenn Davis v. State of Mississippi
2013-KM-00167-COA |  | Hand Down List
Maxwell, James D., II
Cynthia Ann Faulkner v. State of Mississippi
2013-KA-00450-COA | 3/4/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Cynthia Ann Faulkner v. State of Mississippi
2013-KA-00450-COA | 3/4/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Dana Gail Hall v. James K. Hall, III
2012-CA-02008-COA | 8/27/2012 | Hand Down List
Fair, Eugene Love, Jr.
Dana Gail Hall v. James K. Hall, III
2012-CA-02008-COA | 8/27/2012 | Hand Down List
Fair, Eugene Love, Jr.
Dana J. Davis v. Jason Hindman
2012-CA-01728-COA | 9/18/2012 | Hand Down List
Roberts, Larry E.
Dana J. Davis v. Jason Hindman
2012-CA-01728-COA | 9/18/2012 | Hand Down List
Roberts, Larry E.
Daniel Clack v. City of Ridgeland, Mississippi
2013-KM-00453-COA | 3/7/2013 | Hand Down List
Roberts, Larry E.
Daniel Clack v. City of Ridgeland, Mississippi
2013-KM-00453-COA | 3/7/2013 | Hand Down List
Roberts, Larry E.
Daniel Wayne Byers v. State of Mississippi
2013-KA-00571-COA | 2/7/2013 | Hand Down List
Barnes, Donna M.
Daniel Wayne Byers v. State of Mississippi
2013-KA-00571-COA | 2/7/2013 | Hand Down List
Barnes, Donna M.
Danny Bufkin v. Ronald King
2013-CP-00392-COA | 2/12/2013 | Hand Down List
Barnes, Donna M.
Danny Bufkin v. Ronald King
2013-CP-00392-COA | 2/12/2013 | Hand Down List
Barnes, Donna M.
Danny Smith v. State of Mississippi
2012-CP-00790-COA |  | Hand Down List
Barnes, Donna M.
Danny Smith v. State of Mississippi
2012-CP-00790-COA |  | Hand Down List
Barnes, Donna M.
Dareous Rico Bryant v. State of Mississippi
2012-KA-02053-COA | 9/13/2012 | Hand Down List
James, Ceola
Dareous Rico Bryant v. State of Mississippi
2012-KA-02053-COA | 9/13/2012 | Hand Down List
James, Ceola
Darrell Tillis v. State of Mississippi
2012-KA-00854-COA | 12/1/2011 | Hand Down List
Carlton, Virginia Carter
Darrell Tillis v. State of Mississippi
2012-KA-00854-COA | 12/1/2011 | Hand Down List
Carlton, Virginia Carter
David Bursey v. State of Mississippi
2013-CT-00046-SCT |  | Hand Down List
Fair, Eugene Love, Jr.
David Bursey v. State of Mississippi
2013-CT-00046-SCT |  | Hand Down List
Fair, Eugene Love, Jr.
David Lavor Anderson v. State of Mississippi
2012-KA-01608-COA | 8/18/2011 | Hand Down List
Carlton, Virginia Carter
David Lavor Anderson v. State of Mississippi
2012-KA-01608-COA | 8/18/2011 | Hand Down List
Carlton, Virginia Carter
Debra L. Kent v. Mississippi Department of Employment Security
2013-CC-00284-COA | 1/15/2013 | Hand Down List
Lee, L. Joseph
Debra L. Kent v. Mississippi Department of Employment Security
2013-CC-00284-COA | 1/15/2013 | Hand Down List
Lee, L. Joseph
Debra Ludwig v. State of Mississippi
2012-CT-01552-COA | 9/6/2012 | Hand Down List
Roberts, Larry E.
Debra Ludwig v. State of Mississippi
2012-CT-01552-COA | 9/6/2012 | Hand Down List
Roberts, Larry E.
Deidi Rodrigue v. Mitchell Rodrigue
2012-CA-01835-COA | 10/11/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Deidi Rodrigue v. Mitchell Rodrigue
2012-CA-01835-COA | 10/11/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Denise Anthony v. Mississippi Department of Employment Security
2013-CC-00541-COA | 3/22/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Denise Anthony v. Mississippi Department of Employment Security
2013-CC-00541-COA | 3/22/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Dennis Jerome Beal v. State of Mississippi
2012-KA-00182-COA | 12/14/2011 | Hand Down List
Roberts, Larry E.
Dennis Jerome Beal v. State of Mississippi
2012-KA-00182-COA | 12/14/2011 | Hand Down List
Roberts, Larry E.
Denorris Howell v. State of Mississippi
2012-KA-01814-COA | 11/1/2012 | Hand Down List
Carlton, Virginia Carter
Denorris Howell v. State of Mississippi
2012-KA-01814-COA | 11/1/2012 | Hand Down List
Carlton, Virginia Carter
Derrick M. Amos, Sr. v. Jackson Public School District
2012-CA-00352-COA |  | Hand Down List
James, Ceola
Derrick M. Amos, Sr. v. Jackson Public School District
2012-CA-00352-COA |  | Hand Down List
James, Ceola
Derrick Stokes v. State of Mississippi
2013-CT-00887-COA | 5/10/2013 | Hand Down List
Carlton, Virginia Carter
Derrick Stokes v. State of Mississippi
2013-CT-00887-COA | 5/10/2013 | Hand Down List
Carlton, Virginia Carter
Detrick Dewayne Harris v. State of Mississippi
2012-KA-01044-COA | 6/13/2012 | Hand Down List
Irving, Tyree
Detrick Dewayne Harris v. State of Mississippi
2012-KA-01044-COA | 6/13/2012 | Hand Down List
Irving, Tyree
Donald Breeden v. Willie Faye Breeden Buchanan
2012-CA-00326-COA | 2/10/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Donald Breeden v. Willie Faye Breeden Buchanan
2012-CA-00326-COA | 2/10/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Donald Nolan Ainsworth v. Melanie Reeves Ainsworth
2013-CA-00148-COA | 12/21/2012 | Hand Down List
Lee, L. Joseph
Donald Nolan Ainsworth v. Melanie Reeves Ainsworth
2013-CA-00148-COA | 12/21/2012 | Hand Down List
Lee, L. Joseph
Donna Lee Mayes Proctor v. Douglas Roger Proctor
2012-CT-00760-COA | 3/13/2012 | Hand Down List
Barnes, Donna M.
Donna Lee Mayes Proctor v. Douglas Roger Proctor
2012-CT-00760-COA | 3/13/2012 | Hand Down List
Barnes, Donna M.
Donna Sue Cates v. William W. Woods, III
2012-CA-01069-COA | 5/30/2012 | Hand Down List
Barnes, Donna M.
Donna Sue Cates v. William W. Woods, III
2012-CA-01069-COA | 5/30/2012 | Hand Down List
Barnes, Donna M.
Douglas Davis v. State of Mississippi
2013-CP-00915-COA | 5/1/2013 | Hand Down List
Fair, Eugene Love, Jr.
Douglas Davis v. State of Mississippi
2013-CP-00915-COA | 5/1/2013 | Hand Down List
Fair, Eugene Love, Jr.
Dwight Lott v. State of Mississippi
2013-CP-00308-COA | 1/29/2013 | Hand Down List
Barnes, Donna M.
Dwight Lott v. State of Mississippi
2013-CP-00308-COA | 1/29/2013 | Hand Down List
Barnes, Donna M.
Eddie Beals v. State of Mississippi
2013-CP-00777-COA | 4/12/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Eddie Beals v. State of Mississippi
2013-CP-00777-COA | 4/12/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Eddie J. Davis v. Mississippi Department of Employment Security
2013-CC-01584-COA | 9/6/2013 | Hand Down List
Maxwell, James D., II
Eddie J. Davis v. Mississippi Department of Employment Security
2013-CC-01584-COA | 9/6/2013 | Hand Down List
Maxwell, James D., II
Eddie James Carthan v. Town of Tchula, Mississippi
2012-CA-01347-COA | 7/12/2012 | Hand Down List
Lee, L. Joseph
Eddie James Carthan v. Town of Tchula, Mississippi
2012-CA-01347-COA | 7/12/2012 | Hand Down List
Lee, L. Joseph
Eddie Joseph Brown v. State of Mississippi
2012-CT-01256-COA | 3/14/2012 | Hand Down List
Ishee, David Michael
Eddie Joseph Brown v. State of Mississippi
2012-CT-01256-COA | 3/14/2012 | Hand Down List
Ishee, David Michael
Eddie Lee Harris v. State of Mississippi
2013-KA-00489-COA | 3/15/2013 | Hand Down List
Fair, Eugene Love, Jr.
Eddie Lee Harris v. State of Mississippi
2013-KA-00489-COA | 3/15/2013 | Hand Down List
Fair, Eugene Love, Jr.
Edmond K. Brown, Jr. v. State of Mississippi
2013-KA-00060-COA | 1/3/2013 | Hand Down List
Roberts, Larry E.
Edmond K. Brown, Jr. v. State of Mississippi
2013-KA-00060-COA | 1/3/2013 | Hand Down List
Roberts, Larry E.
Edward Robertson v. State of Mississippi
2012-CP-01455-COA | 8/16/2012 | Hand Down List
Maxwell, James D., II
Edward Robertson v. State of Mississippi
2012-CP-01455-COA | 8/16/2012 | Hand Down List
Maxwell, James D., II
Edwin Love Holt v. Mississippi State Board of Dental Examiners
2012-SA-01370-COA |  | Hand Down List
Roberts, Larry E.
Edwin Love Holt v. Mississippi State Board of Dental Examiners
2012-SA-01370-COA |  | Hand Down List
Roberts, Larry E.
Elizabeth Carol King v. Singing River Health System
2012-CA-01449-COA | 7/31/2012 | Hand Down List
Barnes, Donna M.
Elray Jones v. Mea, Inc.
2013-CA-00463-COA | 8/16/2012 | Hand Down List
Maxwell, James D., II
Elray Jones v. Mea, Inc.
2013-CA-00463-COA | 8/16/2012 | Hand Down List
Maxwell, James D., II
Emanuel Sanders v. State of Mississippi
2013-CP-01106-COA | 5/29/2013 | Hand Down List
Ishee, David Michael
Emanuel Sanders v. State of Mississippi
2013-CP-01106-COA | 5/29/2013 | Hand Down List
Ishee, David Michael
Eric Jerome Boone v. State of Mississippi
2012-CT-01396-SCT | 8/6/2012 | Hand Down List
James, Ceola
Eric Jerome Boone v. State of Mississippi
2012-CT-01396-SCT | 8/6/2012 | Hand Down List
James, Ceola
Eric Wallace v. State of Mississippi
2013-KA-00173-COA | 12/14/2012 | Hand Down List
Fair, Eugene Love, Jr.
Eric Wallace v. State of Mississippi
2013-KA-00173-COA | 12/14/2012 | Hand Down List
Fair, Eugene Love, Jr.
Ernest Lane, III v. Ronald D. Lampkin
2013-CA-00554-COA | 3/19/2013 | Hand Down List
Carlton, Virginia Carter
Ernest Lane, III v. Ronald D. Lampkin
2013-CA-00554-COA | 3/19/2013 | Hand Down List
Carlton, Virginia Carter
Estus James Smith v. State of Mississippi
2013-CP-00233-SCT | 1/14/2013 | Hand Down List
James, Ceola
Estus James Smith v. State of Mississippi
2013-CP-00233-SCT | 1/14/2013 | Hand Down List
James, Ceola
Ethel Williams v. Mansfield Langston
2012-CA-01799-COA | 2/2/2012 | Hand Down List
Ishee, David Michael
Ethel Williams v. Mansfield Langston
2012-CA-01799-COA | 2/2/2012 | Hand Down List
Ishee, David Michael
Forrest General Hospital v. Michael Humphrey
2013-WC-00424-COA | 2/7/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Forrest General Hospital v. Michael Humphrey
2013-WC-00424-COA | 2/7/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Frank D. Hall v. State of Mississippi
2013-CA-00307-COA | 2/5/2013 | Hand Down List
James, Ceola
Frank D. Hall v. State of Mississippi
2013-CA-00307-COA | 2/5/2013 | Hand Down List
James, Ceola
Franklin D. Lewis v. Constance Slaughter Harvey
2012-CA-01623-COA | 8/30/2012 | Hand Down List
Maxwell, James D., II
Franklin D. Lewis v. Constance Slaughter Harvey
2012-CA-01623-COA | 8/30/2012 | Hand Down List
Maxwell, James D., II
Freddie Lee Martin v. State of Mississippi
2013-CP-00221-COA | 1/8/2013 | Hand Down List
James, Ceola
Freddie Lee Martin v. State of Mississippi
2013-CP-00221-COA | 1/8/2013 | Hand Down List
James, Ceola
Frederick D. Small v. State of Mississippi
2013-CP-00989-COA |  | Hand Down List
Barnes, Donna M.
Frederick D. Small v. State of Mississippi
2013-CP-00989-COA |  | Hand Down List
Barnes, Donna M.
Frederick Devon Pritchett v. State of Mississippi
2012-KA-01998-COA | 11/28/2012 | Hand Down List
James, Ceola
Frederick Devon Pritchett v. State of Mississippi
2012-KA-01998-COA | 11/28/2012 | Hand Down List
James, Ceola
Gabriel McDowell v. State of Mississippi
2013-CP-01229-COA | 6/10/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Gabriel McDowell v. State of Mississippi
2013-CP-01229-COA | 6/10/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Gae Dickinson v. Jonathan Vanderburg
2013-CA-00044-COA | 12/7/2012 | Hand Down List
Lee, L. Joseph
Gae Dickinson v. Jonathan Vanderburg
2013-CA-00044-COA | 12/7/2012 | Hand Down List
Lee, L. Joseph
George Aaron v. Annie Aaron
2013-CA-00925-COA | 5/13/2013 | Hand Down List
Fair, Eugene Love, Jr.
George Aaron v. Annie Aaron
2013-CA-00925-COA | 5/13/2013 | Hand Down List
Fair, Eugene Love, Jr.
George Huey v. RGIS Inventory Specialists
2013-CT-00310-SCT |  | Hand Down List
Roberts, Larry E.
George Huey v. RGIS Inventory Specialists
2013-CT-00310-SCT |  | Hand Down List
Roberts, Larry E.
George Michael Bass v. State of Mississippi
2013-CP-01230-COA | 6/21/2013 | Hand Down List
Ishee, David Michael
George Michael Bass v. State of Mississippi
2013-CP-01230-COA | 6/21/2013 | Hand Down List
Ishee, David Michael
Grace West Jennings v. Thomas S. Shuler
2012-CT-01122-SCT | 8/16/2012 | Hand Down List
Maxwell, James D., II
Grace West Jennings v. Thomas S. Shuler
2012-CT-01122-SCT | 8/16/2012 | Hand Down List
Maxwell, James D., II
Gray Properties, LLC v. Utility Constructors
2012-CA-01939-COA | 3/14/2012 | Hand Down List
Barnes, Donna M.
Greg Nethery v. William W. Dreher
2013-CA-00013-COA | 9/26/2012 | Hand Down List
Carlton, Virginia Carter
Greg Nethery v. William W. Dreher
2013-CA-00013-COA | 9/26/2012 | Hand Down List
Carlton, Virginia Carter
Greg Williams v. State of Mississippi
2012-KM-01883-COA | 10/22/2012 | Hand Down List
Roberts, Larry E.
Greg Williams v. State of Mississippi
2012-KM-01883-COA | 10/22/2012 | Hand Down List
Roberts, Larry E.
Gregory K. Price v. John S. Pereira
2012-CA-00304-COA | 5/17/2010 | Hand Down List
Carlton, Virginia Carter
Gregory K. Price v. John S. Pereira
2012-CA-00304-COA | 5/17/2010 | Hand Down List
Carlton, Virginia Carter
Harold Maurice Dean v. State of Mississippi
2013-KA-01717-COA | 8/21/2013 | Hand Down List
Lee, L. Joseph
Harold Maurice Dean v. State of Mississippi
2013-KA-01717-COA | 8/21/2013 | Hand Down List
Lee, L. Joseph
Harrison County Utility Authority v. Helen Peterson Walker
2012-CT-00769-COA | 5/1/2012 | Hand Down List
James, Ceola
Harrison County Utility Authority v. Helen Peterson Walker
2012-CT-00769-COA | 5/1/2012 | Hand Down List
James, Ceola
Health Care Medical, Inc. v. Christy Good
2013-CA-00605-COA | 3/12/2013 | Hand Down List
Lee, L. Joseph
Health Care Medical, Inc. v. Christy Good
2013-CA-00605-COA | 3/12/2013 | Hand Down List
Lee, L. Joseph
Henry J. Laneri, III v. State of Mississippi
2013-CP-00941-COA | 4/17/2013 | Hand Down List
Carlton, Virginia Carter
Henry J. Laneri, III v. State of Mississippi
2013-CP-00941-COA | 4/17/2013 | Hand Down List
Carlton, Virginia Carter
Howard O'Gwin v. Isle of Capri-Natchez, Inc.
2013-CA-00373-COA | 1/2/2013 | Hand Down List
Maxwell, James D., II
Howard O'Gwin v. Isle of Capri-Natchez, Inc.
2013-CA-00373-COA | 1/2/2013 | Hand Down List
Maxwell, James D., II
Ice Plant, Inc. v. Tavaris Grace
2012-CA-01150-COA | 5/29/2012 | Hand Down List
Barnes, Donna M.
Ira M. Pruitt v. Lena M. Walker Pruitt
2013-CA-00418-COA | 10/18/2012 | Hand Down List
Roberts, Larry E.
Ira M. Pruitt v. Lena M. Walker Pruitt
2013-CA-00418-COA | 10/18/2012 | Hand Down List
Roberts, Larry E.
Jack R. Darden v. Wilkinson County Board of Supervisors
2012-CA-01934-COA | 11/7/2012 | Hand Down List
Maxwell, James D., II
Jack R. Darden v. Wilkinson County Board of Supervisors
2012-CA-01934-COA | 11/7/2012 | Hand Down List
Maxwell, James D., II
Jackson Williams, Jr. v. State of Mississippi
2012-CP-01634-COA | 1/18/2012 | Hand Down List
Ishee, David Michael
Jackson Williams, Jr. v. State of Mississippi
2012-CP-01634-COA | 1/18/2012 | Hand Down List
Ishee, David Michael
James Albert Hanlin v. Melanie D. Hanlin
2013-CA-00063-COA | 9/27/2012 | Hand Down List
Lee, L. Joseph
James Albert Hanlin v. Melanie D. Hanlin
2013-CA-00063-COA | 9/27/2012 | Hand Down List
Lee, L. Joseph
James Alfred Beeks v. State of Mississippi
2012-CA-01439-COA | 10/17/2011 | Hand Down List
Fair, Eugene Love, Jr.
James Alfred Beeks v. State of Mississippi
2012-CA-01439-COA | 10/17/2011 | Hand Down List
Fair, Eugene Love, Jr.
James E. Fuller, Jr. v. Rachel Weidner
2013-CA-00963-COA | 5/7/2013 | Hand Down List
Lee, L. Joseph
James E. Fuller, Jr. v. Rachel Weidner
2013-CA-00963-COA | 5/7/2013 | Hand Down List
Lee, L. Joseph
James H. Bosarge v. State of Mississippi
2013-CP-00723-COA | 4/8/2013 | Hand Down List
Fair, Eugene Love, Jr.
James H. Bosarge v. State of Mississippi
2013-CP-00723-COA | 4/8/2013 | Hand Down List
Fair, Eugene Love, Jr.
James Lewis v. State of Mississippi
2013-KA-00337-COA | 11/20/2012 | Hand Down List
Barnes, Donna M.
James Lewis v. State of Mississippi
2013-KA-00337-COA | 11/20/2012 | Hand Down List
Barnes, Donna M.
James Loftin v. Jefferson Davis County School District
2013-CA-00041-COA | 6/19/2012 | Hand Down List
Fair, Eugene Love, Jr.
James Loftin v. Jefferson Davis County School District
2013-CA-00041-COA | 6/19/2012 | Hand Down List
Fair, Eugene Love, Jr.
James Luster v. State of Mississippi
2013-KA-00552-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
James Luster v. State of Mississippi
2013-KA-00552-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
James Magee v. State of Mississippi
2013-CP-00289-COA | 3/1/2013 | Hand Down List
Carlton, Virginia Carter
James Magee v. State of Mississippi
2013-CP-00289-COA | 3/1/2013 | Hand Down List
Carlton, Virginia Carter
James Martin Busby v. State of Mississippi
2013-KA-00531-COA | 3/7/2013 | Hand Down List
Lee, L. Joseph
James Martin Busby v. State of Mississippi
2013-KA-00531-COA | 3/7/2013 | Hand Down List
Lee, L. Joseph
Jason A. Pruitt v. Lisa S. Pruitt
2013-CA-00128-COA | 12/20/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Jason A. Pruitt v. Lisa S. Pruitt
2013-CA-00128-COA | 12/20/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Jason T. Zebert v. Thomas E. Baker
2012-CA-01480-COA | 7/18/2012 | Hand Down List
Barnes, Donna M.
Jason T. Zebert v. Thomas E. Baker
2012-CA-01480-COA | 7/18/2012 | Hand Down List
Barnes, Donna M.
Jay Alan Cook v. Mercedes Josephine Peralta Cook
2012-CA-01186-COA | 6/18/2012 | Hand Down List
Carlton, Virginia Carter
Jay Alan Cook v. Mercedes Josephine Peralta Cook
2012-CA-01186-COA | 6/18/2012 | Hand Down List
Carlton, Virginia Carter
Jeanette W. Brown v. Virginia K. Jones
2013-CA-00032-COA | 6/6/2012 | Hand Down List
James, Ceola
Jeanette W. Brown v. Virginia K. Jones
2013-CA-00032-COA | 6/6/2012 | Hand Down List
James, Ceola
Jeffery Ramer v. State of Mississippi
2013-KA-00596-COA | 3/11/2013 | Hand Down List
Roberts, Larry E.
Jeffery Ramer v. State of Mississippi
2013-KA-00596-COA | 3/11/2013 | Hand Down List
Roberts, Larry E.
Jeffrey Holman v. State of Mississippi
2013-CA-00484-COA | 3/6/2013 | Hand Down List
Fair, Eugene Love, Jr.
Jeffrey Holman v. State of Mississippi
2013-CA-00484-COA | 3/6/2013 | Hand Down List
Fair, Eugene Love, Jr.
Jeffrey Rivers v. State of Mississippi
2013-CP-00509-COA | 2/27/2013 | Hand Down List
Fair, Eugene Love, Jr.
Jeffrey Rivers v. State of Mississippi
2013-CP-00509-COA | 2/27/2013 | Hand Down List
Fair, Eugene Love, Jr.
Jerica Evans v. State of Mississippi
2012-CT-01067-COA | 4/13/2012 | Hand Down List
Barnes, Donna M.
Jerry Don Fairley v. State of Mississippi
2012-CP-01950-COA | 12/10/2012 | Hand Down List
Lee, L. Joseph
Jerry Don Fairley v. State of Mississippi
2012-CP-01950-COA | 12/10/2012 | Hand Down List
Lee, L. Joseph
Jerry Williams v. Mueller Copper Tube Company, Inc.
2012-CT-01964-SCT | 10/31/2012 | Hand Down List
Fair, Eugene Love, Jr.
Jerry Williams v. Mueller Copper Tube Company, Inc.
2012-CT-01964-SCT | 10/31/2012 | Hand Down List
Fair, Eugene Love, Jr.
Jimmie D. Minshew v. State of Mississippi
2013-CP-00703-COA | 3/20/2013 | Hand Down List
James, Ceola
Jimmie D. Minshew v. State of Mississippi
2013-CP-00703-COA | 3/20/2013 | Hand Down List
James, Ceola
Jimmy C. Reed, Jr. v. Gail Gillespie Reed
2013-CA-00947-COA | 5/20/2013 | Hand Down List
Ishee, David Michael
Jimmy C. Reed, Jr. v. Gail Gillespie Reed
2013-CA-00947-COA | 5/20/2013 | Hand Down List
Ishee, David Michael
Jimmy W. Zeigler v. Tim Nolan
2013-CA-00404-COA | 1/8/2013 | Hand Down List
Irving, Tyree
Jimmy W. Zeigler v. Tim Nolan
2013-CA-00404-COA | 1/8/2013 | Hand Down List
Irving, Tyree
Jo Ann Miller v. Johnson Controls
2013-WC-00016-COA | 11/30/2012 | Hand Down List
Fair, Eugene Love, Jr.
Jo Ann Miller v. Johnson Controls
2013-WC-00016-COA | 11/30/2012 | Hand Down List
Fair, Eugene Love, Jr.
Joe McGinty v. Grand Casinos of Mississippi, Inc.- Biloxi
2012-CA-01777-COA | 9/21/2012 | Hand Down List
Barnes, Donna M.
Joe McGinty v. Grand Casinos of Mississippi, Inc.- Biloxi
2012-CA-01777-COA | 9/21/2012 | Hand Down List
Barnes, Donna M.
Joe O'Neal v. State of Mississippi
2013-CP-00685-COA | 4/11/2013 | Hand Down List
Lee, L. Joseph
Joe O'Neal v. State of Mississippi
2013-CP-00685-COA | 4/11/2013 | Hand Down List
Lee, L. Joseph
John Jackson v. State of Mississippi
2012-KA-00226-COA | 12/27/2011 | Hand Down List
Ishee, David Michael
John Jackson v. State of Mississippi
2012-KA-00226-COA | 12/27/2011 | Hand Down List
Ishee, David Michael
John Jackson v. State of Mississippi
2013-CP-00494-COA | 3/28/2013 | Hand Down List
Carlton, Virginia Carter
John Jackson v. State of Mississippi
2013-CP-00494-COA | 3/28/2013 | Hand Down List
Carlton, Virginia Carter
John Oliver Hersey v. Cindy Teresa Hersey Gratton
2013-CA-00169-COA | 12/21/2012 | Hand Down List
Lee, L. Joseph
John Oliver Hersey v. Cindy Teresa Hersey Gratton
2013-CA-00169-COA | 12/21/2012 | Hand Down List
Lee, L. Joseph
John Thomas Rainey, Jr. v. State of Mississippi
2013-CP-00349-COA | 1/24/2013 | Hand Down List
Lee, L. Joseph
Johnny Lee Floyd v. State of Mississippi
2012-KA-01715-COA | 7/9/2012 | Hand Down List
Lee, L. Joseph
Johnny Lee Floyd v. State of Mississippi
2012-KA-01715-COA | 7/9/2012 | Hand Down List
Lee, L. Joseph
Johnson Trucking Company v. Peterbilt of Mississippi, Inc.
2012-CT-01908-SCT | 8/13/2012 | Hand Down List
Ishee, David Michael
Johnson Trucking Company v. Peterbilt of Mississippi, Inc.
2012-CT-01908-SCT | 8/13/2012 | Hand Down List
Ishee, David Michael
Jonathan Mosby v. State of Mississippi
2012-KA-00941-COA | 4/15/2011 | Hand Down List
James, Ceola
Jonathan Mosby v. State of Mississippi
2012-KA-00941-COA | 4/15/2011 | Hand Down List
James, Ceola
Jonathan Spencer Shotts v. City of Madison, Mississippi
2013-KM-01108-COA | 3/1/2013 | Hand Down List
Fair, Eugene Love, Jr.
Jonathan Spencer Shotts v. City of Madison, Mississippi
2013-KM-01108-COA | 3/1/2013 | Hand Down List
Fair, Eugene Love, Jr.
Jordan Davis v. State of Mississippi
2012-KA-00863-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
Jordan Davis v. State of Mississippi
2012-KA-00863-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
Joseph L. Johnson v. State of Mississippi
2013-CT-00470-COA | 3/8/2013 | Hand Down List
Carlton, Virginia Carter
Joseph Ronald Hartfield v. State of Mississippi
2012-CT-01232-SCT | 7/11/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Joseph Ronald Hartfield v. State of Mississippi
2012-CT-01232-SCT | 7/11/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Joyce A. Banks v. Brinker Mississippi, Inc.
2013-CA-00521-COA | 2/25/2013 | Hand Down List
Carlton, Virginia Carter
Joyce A. Banks v. Brinker Mississippi, Inc.
2013-CA-00521-COA | 2/25/2013 | Hand Down List
Carlton, Virginia Carter
Joyce Cockrell v. Carl Langley Cockrell
2013-CA-00031-COA |  | Hand Down List
Fair, Eugene Love, Jr.
Joyce Cockrell v. Carl Langley Cockrell
2013-CA-00031-COA |  | Hand Down List
Fair, Eugene Love, Jr.
Julia Beth Lott v. Robert E. Alexander
2013-CA-00104-COA | 1/7/2013 | Hand Down List
Fair, Eugene Love, Jr.
Julia Beth Lott v. Robert E. Alexander
2013-CA-00104-COA | 1/7/2013 | Hand Down List
Fair, Eugene Love, Jr.
Juquin Wilson v. State of Mississippi
2013-KA-00513-COA | 3/13/2013 | Hand Down List
James, Ceola
Juquin Wilson v. State of Mississippi
2013-KA-00513-COA | 3/13/2013 | Hand Down List
James, Ceola
Justin Howse v. Brentwood Behavioral Healthcare of Mississippi
2013-CA-00893-COA | 5/15/2013 | Hand Down List
James, Ceola
Justin Howse v. Brentwood Behavioral Healthcare of Mississippi
2013-CA-00893-COA | 5/15/2013 | Hand Down List
James, Ceola
Justin James v. State of Mississippi
2011-CT-00210-COA | 10/21/2010 | Hand Down List
Carlton, Virginia Carter
Justin James v. State of Mississippi
2011-CT-00210-COA | 10/21/2010 | Hand Down List
Carlton, Virginia Carter
Justin Matthews v. State of Mississippi
2012-KA-01747-COA | 10/8/2012 | Hand Down List
Maxwell, James D., II
Justin Matthews v. State of Mississippi
2012-KA-01747-COA | 10/8/2012 | Hand Down List
Maxwell, James D., II
Karen Garson v. Circus Circus Mississippi, Inc.
2013-CA-00498-COA |  | Hand Down List
Roberts, Larry E.
Karen Garson v. Circus Circus Mississippi, Inc.
2013-CA-00498-COA |  | Hand Down List
Roberts, Larry E.
Kathleen Owens v. Mississippi Department of Employment Security
2013-CC-00809-COA | 5/7/2013 | Hand Down List
Maxwell, James D., II
Kathleen Owens v. Mississippi Department of Employment Security
2013-CC-00809-COA | 5/7/2013 | Hand Down List
Maxwell, James D., II
Kathy May Huber v. Cecilia Eubanks
2012-CT-00030-SCT | 11/22/2011 | Hand Down List
Carlton, Virginia Carter
Kenneth Flowers v. State of Mississippi
2012-CT-01405-COA | 2/6/2012 | Hand Down List
Carlton, Virginia Carter
Kenneth Flowers v. State of Mississippi
2012-CT-01405-COA | 2/6/2012 | Hand Down List
Carlton, Virginia Carter
Kenneth M. Crook v. City of Madison, Mississippi
2013-KM-00081-COA | 12/12/2012 | Hand Down List
Ishee, David Michael
Kerry Cleave Hamlett v. State of Mississippi
2012-CP-01674-COA | 9/10/2012 | Hand Down List
Lee, L. Joseph
Kerry Cleave Hamlett v. State of Mississippi
2012-CP-01674-COA | 9/10/2012 | Hand Down List
Lee, L. Joseph
Kevin Leigh Williams v. State of Mississippi
2013-KA-00660-COA | 4/1/2013 | Hand Down List
Roberts, Larry E.
Kevin Leigh Williams v. State of Mississippi
2013-KA-00660-COA | 4/1/2013 | Hand Down List
Roberts, Larry E.
Kevin M. Atkins v. Old River Supply, Inc.
2013-CT-01248-SCT | 6/21/2013 | Hand Down List
Maxwell, James D., II
Kevin M. Atkins v. Old River Supply, Inc.
2013-CT-01248-SCT | 6/21/2013 | Hand Down List
Maxwell, James D., II
Kevin Reynolds v. State of Mississippi
2012-KA-01566-COA | 8/21/2012 | Hand Down List
Barnes, Donna M.
Kevin Reynolds v. State of Mississippi
2012-KA-01566-COA | 8/21/2012 | Hand Down List
Barnes, Donna M.
Kevin Thompson v. A & Z, Inc.
2012-CA-01945-COA | 11/14/2012 | Hand Down List
Barnes, Donna M.
Kevin Thompson v. A & Z, Inc.
2012-CA-01945-COA | 11/14/2012 | Hand Down List
Barnes, Donna M.
Kimberly Denise Wylie v. James Willard Wylie
2013-CA-00594-COA | 3/25/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Kimberly Denise Wylie v. James Willard Wylie
2013-CA-00594-COA | 3/25/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
King Metal Buildings, Inc. v. Renasant Insurance, Inc.
2012-CA-01885-COA | 11/7/2012 | Hand Down List
Carlton, Virginia Carter
King Metal Buildings, Inc. v. Renasant Insurance, Inc.
2012-CA-01885-COA | 11/7/2012 | Hand Down List
Carlton, Virginia Carter
Lamario Smoot v. State of Mississippi
2012-KA-00911-COA | 10/5/2011 | Hand Down List
Fair, Eugene Love, Jr.
Lamario Smoot v. State of Mississippi
2012-KA-00911-COA | 10/5/2011 | Hand Down List
Fair, Eugene Love, Jr.
Larry Jarrett v. Robert Houston Dillard
2013-CA-00035-COA | 12/4/2012 | Hand Down List
Roberts, Larry E.
Larry Jarrett v. Robert Houston Dillard
2013-CA-00035-COA | 12/4/2012 | Hand Down List
Roberts, Larry E.
Laura K. Strickland Rosser v. Abraham J. Morris
2012-CA-00585-COA | 3/12/2012 | Hand Down List
Barnes, Donna M.
Laura K. Strickland Rosser v. Abraham J. Morris
2012-CA-00585-COA | 3/12/2012 | Hand Down List
Barnes, Donna M.
Lecia Elizabeth Spriggs v. Kurt Alan Buechler
2012-CT-01180-SCT | 2/8/2012 | Hand Down List
Barnes, Donna M.
Lecia Elizabeth Spriggs v. Kurt Alan Buechler
2012-CT-01180-SCT | 2/8/2012 | Hand Down List
Barnes, Donna M.
Lee Martinez Walker v. State of Mississippi
2013-CP-00311-COA | 1/10/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Lee Martinez Walker v. State of Mississippi
2013-CP-00311-COA | 1/10/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Leflore County Board of Supervisors v. Marlin E. Golden, Jr.
2013-WC-00622-COA |  | Hand Down List
Roberts, Larry E.
Leflore County Board of Supervisors v. Marlin E. Golden, Jr.
2013-WC-00622-COA |  | Hand Down List
Roberts, Larry E.
Legacy Hall of Fame, Inc. v. Transport Trailer Service, Inc.
2012-CA-01978-COA | 11/15/2012 | Hand Down List
Fair, Eugene Love, Jr.
Legacy Hall of Fame, Inc. v. Transport Trailer Service, Inc.
2012-CA-01978-COA | 11/15/2012 | Hand Down List
Fair, Eugene Love, Jr.
Lindsey Brandon McBride v. Jimmie Herbert McBride, Jr.
2013-CA-00069-COA | 12/13/2012 | Hand Down List
Roberts, Larry E.
Lindsey Brandon McBride v. Jimmie Herbert McBride, Jr.
2013-CA-00069-COA | 12/13/2012 | Hand Down List
Roberts, Larry E.
Lonnie Massey v. State of Mississippi
2013-CT-00478-SCT | 3/8/2013 | Hand Down List
Fair, Eugene Love, Jr.
Lonnie Massey v. State of Mississippi
2013-CT-00478-SCT | 3/8/2013 | Hand Down List
Fair, Eugene Love, Jr.
Lowndes County, Mississippi v. Hal H.H. McClanahan, III
2013-CA-00406-COA | 2/4/2013 | Hand Down List
Fair, Eugene Love, Jr.
Lowndes County, Mississippi v. Hal H.H. McClanahan, III
2013-CA-00406-COA | 2/4/2013 | Hand Down List
Fair, Eugene Love, Jr.
Manhattan Nursing & Rehabilitation Center, LLC v. Bridget Pace
2012-CA-00025-COA | 12/14/2011 | Hand Down List
Barnes, Donna M.
Manhattan Nursing & Rehabilitation Center, LLC v. Bridget Pace
2012-CA-00025-COA | 12/14/2011 | Hand Down List
Barnes, Donna M.
Marci Harvison Oglesby v. City of Madison, Mississippi
2013-KM-01301-COA | 7/24/2013 | Hand Down List
Ishee, David Michael
Marci Harvison Oglesby v. City of Madison, Mississippi
2013-KM-01301-COA | 7/24/2013 | Hand Down List
Ishee, David Michael
Marilyn Dedeaux v. Lake Caroline Owners Association, Inc.
2013-CA-00671-COA | 4/15/2013 | Hand Down List
Maxwell, James D., II
Marilyn Dedeaux v. Lake Caroline Owners Association, Inc.
2013-CA-00671-COA | 4/15/2013 | Hand Down List
Maxwell, James D., II
Marion Strickland v. Dennis Darby
2012-CA-02044-COA | 12/20/2012 | Hand Down List
Irving, Tyree
Marion Strickland v. Dennis Darby
2012-CA-02044-COA | 12/20/2012 | Hand Down List
Irving, Tyree
Marlon Lavelle Oatis v. State of Mississippi
2013-KA-01011-COA | 5/13/2013 | Hand Down List
Roberts, Larry E.
Marlon Lavelle Oatis v. State of Mississippi
2013-KA-01011-COA | 5/13/2013 | Hand Down List
Roberts, Larry E.
Martez Allen v. State of Mississippi
2013-CP-00886-COA |  | Hand Down List
Maxwell, James D., II
Martez Allen v. State of Mississippi
2013-CP-00886-COA |  | Hand Down List
Maxwell, James D., II
Martez C. Henderson v. State of Mississippi
2013-CA-00387-COA | 2/8/2013 | Hand Down List
Irving, Tyree
Martez C. Henderson v. State of Mississippi
2013-CA-00387-COA | 2/8/2013 | Hand Down List
Irving, Tyree
Marvelle Pryor v. State of Mississippi
2012-KA-00305-COA | 1/11/2012 | Hand Down List
Irving, Tyree
Marvelle Pryor v. State of Mississippi
2012-KA-00305-COA | 1/11/2012 | Hand Down List
Irving, Tyree
Mary Jane Borden v. Edward Shannon Borden
2012-CT-01258-SCT | 6/8/2012 | Hand Down List
Roberts, Larry E.
Mary Jane Borden v. Edward Shannon Borden
2012-CT-01258-SCT | 6/8/2012 | Hand Down List
Roberts, Larry E.
Matthew Burnham v. Dana Burnham
2012-CA-01218-COA | 6/26/2012 | Hand Down List
James, Ceola
Matthew Burnham v. Dana Burnham
2012-CA-01218-COA | 6/26/2012 | Hand Down List
James, Ceola
Matthew Thomas Rickman v. State of Mississippi
2012-KA-01466-COA | 4/20/2012 | Hand Down List
Lee, L. Joseph
Matthew Thomas Rickman v. State of Mississippi
2012-KA-01466-COA | 4/20/2012 | Hand Down List
Lee, L. Joseph
Matthew Thomas Rickman v. State of Mississippi
2013-CT-00388-SCT | 1/29/2013 | Hand Down List
Maxwell, James D., II
Matthew Thomas Rickman v. State of Mississippi
2013-CT-00388-SCT | 1/29/2013 | Hand Down List
Maxwell, James D., II
Maureen B. Speyerer v. Madison County, Mississippi Board of Supervisors
2013-CA-00068-COA | 12/14/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Maureen B. Speyerer v. Madison County, Mississippi Board of Supervisors
2013-CA-00068-COA | 12/14/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Maxine Gibson v. Mississippi Department of Employment Security
2013-CC-00084-COA | 12/18/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Maxine Gibson v. Mississippi Department of Employment Security
2013-CC-00084-COA | 12/18/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Meds, Inc. v. Mississippi Department of Employment Security
2012-CC-01575-COA | 9/4/2012 | Hand Down List
Carlton, Virginia Carter
Meds, Inc. v. Mississippi Department of Employment Security
2012-CC-01575-COA | 9/4/2012 | Hand Down List
Carlton, Virginia Carter
Melanie Diane Keyes v. Dustin Keyes
2013-CA-00059-COA | 12/19/2012 | Hand Down List
Carlton, Virginia Carter
Melanie Diane Keyes v. Dustin Keyes
2013-CA-00059-COA | 12/19/2012 | Hand Down List
Carlton, Virginia Carter
Melvin Tyrone Thornton v. State of Mississippi
2011-CT-01413-COA | 3/3/2011 | Hand Down List
Roberts, Larry E.
Melvin Tyrone Thornton v. State of Mississippi
2011-CT-01413-COA | 3/3/2011 | Hand Down List
Roberts, Larry E.
Michael Deon Taylor v. State of Mississippi
2013-KA-00305-COA | 9/21/2012 | Hand Down List
Roberts, Larry E.
Michael Deon Taylor v. State of Mississippi
2013-KA-00305-COA | 9/21/2012 | Hand Down List
Roberts, Larry E.
Michael Prendergast v. City of Waveland, Mississippi
2013-CA-00555-COA | 3/4/2013 | Hand Down List
Roberts, Larry E.
Michael Prendergast v. City of Waveland, Mississippi
2013-CA-00555-COA | 3/4/2013 | Hand Down List
Roberts, Larry E.
Michael Ray Cochran v. State of Mississippi
2013-CA-00623-COA | 4/3/2013 | Hand Down List
Ishee, David Michael
Michael Ray Cochran v. State of Mississippi
2013-CA-00623-COA | 4/3/2013 | Hand Down List
Ishee, David Michael
Michael Rogowski v. State of Mississippi
2013-CT-00222-COA | 1/3/2013 | Hand Down List
Roberts, Larry E.
Michael Rogowski v. State of Mississippi
2013-CT-00222-COA | 1/3/2013 | Hand Down List
Roberts, Larry E.
Milton Harper v. Banks, Finley, White & Co. of Mississippi, P.C.
2012-WC-00811-COA | 9/27/2011 | Hand Down List
Lee, L. Joseph
Milton Harper v. Banks, Finley, White & Co. of Mississippi, P.C.
2012-WC-00811-COA | 9/27/2011 | Hand Down List
Lee, L. Joseph
Mississippi Department of Public Safety v. Elisha Adcox
2012-CT-01537-COA |  | Hand Down List
James, Ceola
Mississippi Department of Public Safety v. Elisha Adcox
2012-CT-01537-COA |  | Hand Down List
James, Ceola
Mississippi Department of Public Safety v. Olaf R. Raybon
2012-SA-02046-COA | 11/21/2012 | Hand Down List
Barnes, Donna M.
Mississippi Department of Public Safety v. Olaf R. Raybon
2012-SA-02046-COA | 11/21/2012 | Hand Down List
Barnes, Donna M.
Mississippi State Board of Medical Licensure v. Ray Anthony Harron
2013-SA-00654-COA | 3/20/2013 | Hand Down List
Lee, L. Joseph
Mississippi State Board of Medical Licensure v. Ray Anthony Harron
2013-SA-00654-COA | 3/20/2013 | Hand Down List
Lee, L. Joseph
Monique Doss v. Jessica Dixon
2012-CA-01017-COA | 5/16/2012 | Hand Down List
Roberts, Larry E.
Monique Doss v. Jessica Dixon
2012-CA-01017-COA | 5/16/2012 | Hand Down List
Roberts, Larry E.
Natchez-Adams School District v. Tina Bruce
2012-CA-00147-COA | 10/20/2011 | Hand Down List
Roberts, Larry E.
Natchez-Adams School District v. Tina Bruce
2012-CA-00147-COA | 10/20/2011 | Hand Down List
Roberts, Larry E.
Nathaniel Anthony Jackson, Jr. v. State of Mississippi
2013-CP-00579-COA | 1/7/2013 | Hand Down List
Irving, Tyree
Nathaniel Anthony Jackson, Jr. v. State of Mississippi
2013-CP-00579-COA | 1/7/2013 | Hand Down List
Irving, Tyree
Nicholas Thompson v. Mississippi Department of Employment Security
2013-CC-00170-COA | 1/8/2013 | Hand Down List
Fair, Eugene Love, Jr.
Nicholas Thompson v. Mississippi Department of Employment Security
2013-CC-00170-COA | 1/8/2013 | Hand Down List
Fair, Eugene Love, Jr.
Nina H. McGhee v. Virginia Young
2013-CP-00358-COA | 2/7/2013 | Hand Down List
Ishee, David Michael
Nina H. McGhee v. Virginia Young
2013-CP-00358-COA | 2/7/2013 | Hand Down List
Ishee, David Michael
Norman Ferguson v. Mississippi Farm Bureau Casualty Insurance Company
2013-CA-01219-COA | 4/4/2013 | Hand Down List
Barnes, Donna M.
Norman Ferguson v. Mississippi Farm Bureau Casualty Insurance Company
2013-CA-01219-COA | 4/4/2013 | Hand Down List
Barnes, Donna M.
Omar Humphrey v. State of Mississippi
2012-CT-01438-SCT | 7/30/2012 | Hand Down List
James, Ceola
Omar L. Nelson v. State of Mississippi
2013-CP-00835-COA | 5/7/2013 | Hand Down List
Lee, L. Joseph
Omar L. Nelson v. State of Mississippi
2013-CP-00835-COA | 5/7/2013 | Hand Down List
Lee, L. Joseph
Ondre Ray Belton v. State of Mississippi
2013-CP-00213-COA | 1/17/2013 | Hand Down List
Ishee, David Michael
Ondre Ray Belton v. State of Mississippi
2013-CP-00213-COA | 1/17/2013 | Hand Down List
Ishee, David Michael
Patrick Duke v. State of Mississippi
2013-KA-00612-COA | 3/13/2013 | Hand Down List
Maxwell, James D., II
Patrick Duke v. State of Mississippi
2013-KA-00612-COA | 3/13/2013 | Hand Down List
Maxwell, James D., II
Patrick Fluker v. State of Mississippi
2013-CP-00608-COA | 3/26/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Patrick Fluker v. State of Mississippi
2013-CP-00608-COA | 3/26/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Patrick O'Neal Savontrell Montgomery v. Mississippi Baptist Health Systems, Inc.
2012-CT-01459-SCT | 7/19/2012 | Hand Down List
Barnes, Donna M.
Patrick O'Neal Savontrell Montgomery v. Mississippi Baptist Health Systems, Inc.
2012-CT-01459-SCT | 7/19/2012 | Hand Down List
Barnes, Donna M.
Paul Norris v. State of Mississippi
2013-CA-00661-COA | 3/22/2013 | Hand Down List
Maxwell, James D., II
Paul Norris v. State of Mississippi
2013-CA-00661-COA | 3/22/2013 | Hand Down List
Maxwell, James D., II
Paula B. Hicks v. Mark S. Bowling
2013-CA-01174-COA | 4/16/2013 | Hand Down List
Maxwell, James D., II
Paula B. Hicks v. Mark S. Bowling
2013-CA-01174-COA | 4/16/2013 | Hand Down List
Maxwell, James D., II
Perry Investment Group, LLC v. CCBCC Operations, LLC
2012-CA-01729-COA | 9/26/2012 | Hand Down List
Roberts, Larry E.
Perry Investment Group, LLC v. CCBCC Operations, LLC
2012-CA-01729-COA | 9/26/2012 | Hand Down List
Roberts, Larry E.
Philip Halbert Neilson v. Tom Dawson
2012-CA-01792-COA | 9/28/2012 | Hand Down List
Lee, L. Joseph
Philip Halbert Neilson v. Tom Dawson
2012-CA-01792-COA | 9/28/2012 | Hand Down List
Lee, L. Joseph
Rainbow Ranch, Inc. v. John Mike Hardin
2012-CA-01080-COA | 5/16/2012 | Hand Down List
Barnes, Donna M.
Rainbow Ranch, Inc. v. John Mike Hardin
2012-CA-01080-COA | 5/16/2012 | Hand Down List
Barnes, Donna M.
Raymond Fortenberry v. State of Mississippi
2012-KA-01961-COA | 8/20/2012 | Hand Down List
Irving, Tyree
Raymond Fortenberry v. State of Mississippi
2012-KA-01961-COA | 8/20/2012 | Hand Down List
Irving, Tyree
Renita Bishop v. Mississippi Department of Employment Security
2013-CC-01118-COA | 6/3/2013 | Hand Down List
Roberts, Larry E.
Renita Bishop v. Mississippi Department of Employment Security
2013-CC-01118-COA | 6/3/2013 | Hand Down List
Roberts, Larry E.
Residential Advantage Development, LLC v. Dwight Tyrone Ross
2012-CA-01996-COA | 11/8/2012 | Hand Down List
Roberts, Larry E.
Residential Advantage Development, LLC v. Dwight Tyrone Ross
2012-CA-01996-COA | 11/8/2012 | Hand Down List
Roberts, Larry E.
Rhoda Cofield v. Imperial Palace of Mississippi, LLC
2013-CT-00037-SCT | 11/30/2012 | Hand Down List
Lee, L. Joseph
Richard (Rickey) Palermo v. LifeLink Foundation, Inc.
2012-CT-01228-SCT | 12/20/2011 | Hand Down List
Fair, Eugene Love, Jr.
Richard (Rickey) Palermo v. LifeLink Foundation, Inc.
2012-CT-01228-SCT | 12/20/2011 | Hand Down List
Fair, Eugene Love, Jr.
Richard Chapman v. State of Mississippi
2012-CP-01574-COA | 12/10/2012 | Hand Down List
Lee, L. Joseph
Richard Chapman v. State of Mississippi
2012-CP-01574-COA | 12/10/2012 | Hand Down List
Lee, L. Joseph
Richard Dean v. Katie C. Slade
2012-CP-01548-COA | 4/24/2012 | Hand Down List
James, Ceola
Richard Dean v. Katie C. Slade
2012-CP-01548-COA | 4/24/2012 | Hand Down List
James, Ceola
Richard Palmer v. State of Mississippi
2013-CP-00422-COA | 2/22/2013 | Hand Down List
Roberts, Larry E.
Richard Palmer v. State of Mississippi
2013-CP-00422-COA | 2/22/2013 | Hand Down List
Roberts, Larry E.
Ricky Shannon Pierce v. State of Mississippi
2012-KA-01470-COA | 8/7/2012 | Hand Down List
Irving, Tyree
Ricky Shannon Pierce v. State of Mississippi
2012-KA-01470-COA | 8/7/2012 | Hand Down List
Irving, Tyree
Rico Wright v. Terry Henley
2013-CA-00007-COA | 8/2/2012 | Hand Down List
Roberts, Larry E.
Rico Wright v. Terry Henley
2013-CA-00007-COA | 8/2/2012 | Hand Down List
Roberts, Larry E.
Robert Calonkey v. Amory School District
2013-CA-01290-COA | 6/18/2013 | Hand Down List
Maxwell, James D., II
Robert Calonkey v. Amory School District
2013-CA-01290-COA | 6/18/2013 | Hand Down List
Maxwell, James D., II
Robert Cook v. Neshoba County General Hospital
2013-WC-00754-COA |  | Hand Down List
Irving, Tyree
Robert Cook v. Neshoba County General Hospital
2013-WC-00754-COA |  | Hand Down List
Irving, Tyree
Robert Gene Jones v. State of Mississippi
2012-CP-01795-COA | 10/4/2012 | Hand Down List
Roberts, Larry E.
Robert Gene Jones v. State of Mississippi
2012-CP-01795-COA | 10/4/2012 | Hand Down List
Roberts, Larry E.
Robert Lang v. Teresa Beasley
2013-CA-00446-COA | 10/16/2012 | Hand Down List
Fair, Eugene Love, Jr.
Robert Lang v. Teresa Beasley
2013-CA-00446-COA | 10/16/2012 | Hand Down List
Fair, Eugene Love, Jr.
Robert Philip Segrest v. Dennis Wayne Starnes
2012-CA-01364-COA | 7/26/2012 | Hand Down List
Ishee, David Michael
Robert Philip Segrest v. Dennis Wayne Starnes
2012-CA-01364-COA | 7/26/2012 | Hand Down List
Ishee, David Michael
Robert Posey v. Dorothy Pope
2012-CA-00307-COA | 1/25/2012 | Hand Down List
Barnes, Donna M.
Robert Posey v. Dorothy Pope
2012-CA-00307-COA | 1/25/2012 | Hand Down List
Barnes, Donna M.
Robert W. Triplett v. State of Mississippi
2012-KA-01495-COA | 9/5/2012 | Hand Down List
Ishee, David Michael
Robert W. Triplett v. State of Mississippi
2012-KA-01495-COA | 9/5/2012 | Hand Down List
Ishee, David Michael
Robert Williams v. State of Mississippi
2013-KA-00501-COA | 3/4/2013 | Hand Down List
Fair, Eugene Love, Jr.
Robert Williams v. State of Mississippi
2013-KA-00501-COA | 3/4/2013 | Hand Down List
Fair, Eugene Love, Jr.
Roderick Shields v. State of Mississippi
2013-CT-00378-COA | 2/7/2013 | Hand Down List
Fair, Eugene Love, Jr.
Roderick Shields v. State of Mississippi
2013-CT-00378-COA | 2/7/2013 | Hand Down List
Fair, Eugene Love, Jr.
Roventay Tremaine Peden v. State of Mississippi
2012-KA-01192-COA | 7/12/2012 | Hand Down List
Barnes, Donna M.
Roventay Tremaine Peden v. State of Mississippi
2012-KA-01192-COA | 7/12/2012 | Hand Down List
Barnes, Donna M.
Ruben Orlando Benitez v. State of Mississippi
2013-CT-00469-COA | 3/7/2013 | Hand Down List
Carlton, Virginia Carter
Ruben Orlando Benitez v. State of Mississippi
2013-CT-00469-COA | 3/7/2013 | Hand Down List
Carlton, Virginia Carter
Ruben Whittle v. Tango Transport
2013-WC-00034-COA | 12/18/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Ruben Whittle v. Tango Transport
2013-WC-00034-COA | 12/18/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Rufus Brooks, Jr. v. State of Mississippi
2013-CP-00965-COA | 5/15/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Rufus Brooks, Jr. v. State of Mississippi
2013-CP-00965-COA | 5/15/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Rumond Rashad McNair v. State of Mississippi
2012-KA-00856-COA | 1/26/2012 | Hand Down List
James, Ceola
Rumond Rashad McNair v. State of Mississippi
2012-KA-00856-COA | 1/26/2012 | Hand Down List
James, Ceola
Russell Gary O'Brien v. Teri Suzanne O'Brien
2012-CT-00660-SCT | 3/19/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Russell Gary O'Brien v. Teri Suzanne O'Brien
2012-CT-00660-SCT | 3/19/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Ryan Quincy Pugh v. State of Mississippi
2012-CP-01899-COA | 10/4/2012 | Hand Down List
Lee, L. Joseph
Ryan Quincy Pugh v. State of Mississippi
2012-CP-01899-COA | 10/4/2012 | Hand Down List
Lee, L. Joseph
Ryan Savinell v. State of Mississippi
2013-CT-00578-SCT | 3/18/2013 | Hand Down List
James, Ceola
Ryan Savinell v. State of Mississippi
2013-CT-00578-SCT | 3/18/2013 | Hand Down List
James, Ceola
Sally Beebe Smith v. State of Mississippi
2012-KA-01744-COA | 7/23/2012 | Hand Down List
Ishee, David Michael
Sally Beebe Smith v. State of Mississippi
2012-KA-01744-COA | 7/23/2012 | Hand Down List
Ishee, David Michael
Sam Turner v. State of Mississippi
2013-CP-00445-COA | 2/28/2013 | Hand Down List
Barnes, Donna M.
Sam Turner v. State of Mississippi
2013-CP-00445-COA | 2/28/2013 | Hand Down List
Barnes, Donna M.
Sam West Lee v. State of Mississippi
2012-KA-01540-COA | 5/2/2012 | Hand Down List
Irving, Tyree
Sam West Lee v. State of Mississippi
2012-KA-01540-COA | 5/2/2012 | Hand Down List
Irving, Tyree
Sandra Cobb v. State of Mississippi
2013-CA-00512-COA | 3/8/2013 | Hand Down List
Roberts, Larry E.
Sandra Cobb v. State of Mississippi
2013-CA-00512-COA | 3/8/2013 | Hand Down List
Roberts, Larry E.
Sara Pulliam v. Mississippi State Hudspeth Regional Center
2013-WC-00409-COA |  | Hand Down List
Irving, Tyree
Sara Pulliam v. Mississippi State Hudspeth Regional Center
2013-WC-00409-COA |  | Hand Down List
Irving, Tyree
Scooter L. Robinson v. State of Mississippi
2012-CT-00965-COA | 6/7/2012 | Hand Down List
Barnes, Donna M.
Scooter L. Robinson v. State of Mississippi
2012-CT-00965-COA | 6/7/2012 | Hand Down List
Barnes, Donna M.
Scote Renfro v. City of Moss Point
2013-CC-00359-COA | 1/25/2013 | Hand Down List
Roberts, Larry E.
Scote Renfro v. City of Moss Point
2013-CC-00359-COA | 1/25/2013 | Hand Down List
Roberts, Larry E.
Scott Herman Bates v. State of Mississippi
2013-KA-00097-COA | 12/20/2012 | Hand Down List
Maxwell, James D., II
Scott Herman Bates v. State of Mississippi
2013-KA-00097-COA | 12/20/2012 | Hand Down List
Maxwell, James D., II
Sedrick Bernard Price v. State of Mississippi
2012-CP-01846-COA | 10/10/2012 | Hand Down List
Ishee, David Michael
Sedrick Bernard Price v. State of Mississippi
2012-CP-01846-COA | 10/10/2012 | Hand Down List
Ishee, David Michael
Sedrick Joiner v. State of Mississippi
2013-KA-00536-COA | 3/14/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Sedrick Joiner v. State of Mississippi
2013-KA-00536-COA | 3/14/2013 | Hand Down List
Griffis, T. Kenneth, Jr.
Shelton Smiley v. Hercules Concrete Pumping Service, Inc.
2012-WC-01437-COA | 4/5/2012 | Hand Down List
Roberts, Larry E.
Shelton Smiley v. Hercules Concrete Pumping Service, Inc.
2012-WC-01437-COA | 4/5/2012 | Hand Down List
Roberts, Larry E.
Sherrie Allison Miller v. Provident Advertising and Marketing, Inc.
2012-CA-01198-COA | 5/11/2012 | Hand Down List
Barnes, Donna M.
Sherrie Allison Miller v. Provident Advertising and Marketing, Inc.
2012-CA-01198-COA | 5/11/2012 | Hand Down List
Barnes, Donna M.
Sherrill Culpepper v. State of Mississippi
2012-CT-01995-SCT | 12/3/2012 | Hand Down List
Maxwell, James D., II
Sherrill Culpepper v. State of Mississippi
2012-CT-01995-SCT | 12/3/2012 | Hand Down List
Maxwell, James D., II
Stephen Yarbrough v. State of Mississippi
2012-CA-00292-COA | 2/27/2012 | Hand Down List
Roberts, Larry E.
Stephen Yarbrough v. State of Mississippi
2012-CA-00292-COA | 2/27/2012 | Hand Down List
Roberts, Larry E.
Steven Edward Galle v. Isle of Capri Casinos, Inc.
2013-CP-00024-COA | 11/30/2012 | Hand Down List
Fair, Eugene Love, Jr.
Steven Edward Galle v. Isle of Capri Casinos, Inc.
2013-CP-00024-COA | 11/30/2012 | Hand Down List
Fair, Eugene Love, Jr.
Tamara K. Eldridge Summerlin v. George Michael Eldridge
2013-CA-00261-COA | 10/4/2012 | Hand Down List
Lee, L. Joseph
Tamara K. Eldridge Summerlin v. George Michael Eldridge
2013-CA-00261-COA | 10/4/2012 | Hand Down List
Lee, L. Joseph
Tameka Gladney v. Mississippi Department of Employment Security
2013-CC-00689-COA | 3/27/2013 | Hand Down List
Barnes, Donna M.
Tameka Gladney v. Mississippi Department of Employment Security
2013-CC-00689-COA | 3/27/2013 | Hand Down List
Barnes, Donna M.
Tamra W. King v. Joseph Lynn King
2012-CA-00515-COA |  | Hand Down List
Lee, L. Joseph
Tamra W. King v. Joseph Lynn King
2012-CA-00515-COA |  | Hand Down List
Lee, L. Joseph
Tangela Berry v. Tom Carey
2012-CA-01803-COA | 5/14/2012 | Hand Down List
Barnes, Donna M.
Tangela Berry v. Tom Carey
2012-CA-01803-COA | 5/14/2012 | Hand Down List
Barnes, Donna M.
Tanisha Hervey Martin v. Marquis J. Stevenson
2012-CA-01768-COA | 10/16/2012 | Hand Down List
Carlton, Virginia Carter
Tanisha Hervey Martin v. Marquis J. Stevenson
2012-CA-01768-COA | 10/16/2012 | Hand Down List
Carlton, Virginia Carter
Tanya Michaele O'Neal v. Steven Ketchum
2013-CA-00460-COA | 2/27/2013 | Hand Down List
Lee, L. Joseph
Tanya Michaele O'Neal v. Steven Ketchum
2013-CA-00460-COA | 2/27/2013 | Hand Down List
Lee, L. Joseph
Tarvarcus Miller v. State of Mississippi
2012-CT-01630-COA | 7/6/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Tarvarcus Miller v. State of Mississippi
2012-CT-01630-COA | 7/6/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Tellus Operating Group, LLC v. Maxwell Energy, Inc.
2012-CT-00357-SCT | 1/31/2012 | Hand Down List
Carlton, Virginia Carter
Terrance Daryll Rustin v. State of Mississippi
2013-CP-00350-COA | 2/1/2013 | Hand Down List
Barnes, Donna M.
Terrance Daryll Rustin v. State of Mississippi
2013-CP-00350-COA | 2/1/2013 | Hand Down List
Barnes, Donna M.
Terrell U. Williams v. State of Mississippi
2013-CP-00257-COA | 1/28/2013 | Hand Down List
Barnes, Donna M.
Terrell U. Williams v. State of Mississippi
2013-CP-00257-COA | 1/28/2013 | Hand Down List
Barnes, Donna M.
Terry H. Logan, Sr. v. Mississippi Transportation Commission
2013-CA-00258-COA | 9/19/2012 | Hand Down List
Barnes, Donna M.
Terry H. Logan, Sr. v. Mississippi Transportation Commission
2013-CA-00258-COA | 9/19/2012 | Hand Down List
Barnes, Donna M.
The Charter Oak Fire Insurance Company v. B.J. Enterprises of Mississippi, LLC
2012-CA-00519-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
The Charter Oak Fire Insurance Company v. B.J. Enterprises of Mississippi, LLC
2012-CA-00519-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
Thomas J. Hooghe v. State of Mississippi
2013-CP-00845-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
Thomas J. Hooghe v. State of Mississippi
2013-CP-00845-COA |  | Hand Down List
Griffis, T. Kenneth, Jr.
Thomas Jones v. State of Mississippi
2012-KA-02031-COA | 12/12/2012 | Hand Down List
Maxwell, James D., II
Thomas Jones v. State of Mississippi
2012-KA-02031-COA | 12/12/2012 | Hand Down List
Maxwell, James D., II
Thomas Lindley v. State of Mississippi
2013-KM-00502-COA | 3/15/2013 | Hand Down List
Ishee, David Michael
Thomas Lindley v. State of Mississippi
2013-KM-00502-COA | 3/15/2013 | Hand Down List
Ishee, David Michael
Thomas Roy Scott v. State of Mississippi
2013-CP-01252-COA | 7/3/2013 | Hand Down List
Fair, Eugene Love, Jr.
Thomas Roy Scott v. State of Mississippi
2013-CP-01252-COA | 7/3/2013 | Hand Down List
Fair, Eugene Love, Jr.
Tim Hoover v. George Wayne Callen
2012-CA-01602-COA | 8/27/2012 | Hand Down List
Irving, Tyree
Tim Hoover v. George Wayne Callen
2012-CA-01602-COA | 8/27/2012 | Hand Down List
Irving, Tyree
Timothy Carr v. State of Mississippi
2013-CP-01013-COA | 5/23/2013 | Hand Down List
Lee, L. Joseph
Timothy Carr v. State of Mississippi
2013-CP-01013-COA | 5/23/2013 | Hand Down List
Lee, L. Joseph
Timothy Edward Myers v. State of Mississippi
2012-CP-01973-COA | 11/16/2012 | Hand Down List
Ishee, David Michael
Timothy Edward Myers v. State of Mississippi
2012-CP-01973-COA | 11/16/2012 | Hand Down List
Ishee, David Michael
Timothy Lavon Bell v. State of Mississippi
2012-CT-01144-SCT | 6/15/2012 | Hand Down List
Maxwell, James D., II
Timothy Lavon Bell v. State of Mississippi
2012-CT-01144-SCT | 6/15/2012 | Hand Down List
Maxwell, James D., II
Timothy Mosby v. Aurora Cares
2013-CT-01160-SCT |  | Hand Down List
Roberts, Larry E.
Timothy Mosby v. Aurora Cares
2013-CT-01160-SCT |  | Hand Down List
Roberts, Larry E.
Timothy Stratton v. State of Mississippi
2012-KA-01010-COA | 6/12/2012 | Hand Down List
Roberts, Larry E.
Timothy Stratton v. State of Mississippi
2012-KA-01010-COA | 6/12/2012 | Hand Down List
Roberts, Larry E.
Tonya Wallace v. Greenville Public School District
2012-CA-01886-COA |  | Hand Down List
James, Ceola
Tonya Wallace v. Greenville Public School District
2012-CA-01886-COA |  | Hand Down List
James, Ceola
Tyrone K. Thornton v. Big M Transportation Company
2013-CA-00988-COA | 5/17/2013 | Hand Down List
Carlton, Virginia Carter
Tyrone K. Thornton v. Big M Transportation Company
2013-CA-00988-COA | 5/17/2013 | Hand Down List
Carlton, Virginia Carter
Undre Kimmons v. State of Mississippi
2013-CP-01766-COA | 10/1/2013 | Hand Down List
Lee, L. Joseph
Undre Kimmons v. State of Mississippi
2013-CP-01766-COA | 10/1/2013 | Hand Down List
Lee, L. Joseph
Vance Drummer v. State of Mississippi
2012-KA-02004-COA | 11/29/2012 | Hand Down List
Carlton, Virginia Carter
Vance Drummer v. State of Mississippi
2012-KA-02004-COA | 11/29/2012 | Hand Down List
Carlton, Virginia Carter
Violet Meekins v. Eric M. Kennon
2012-CA-02038-COA | 8/21/2012 | Hand Down List
Barnes, Donna M.
Violet Meekins v. Eric M. Kennon
2012-CA-02038-COA | 8/21/2012 | Hand Down List
Barnes, Donna M.
Walter McComb v. State of Mississippi
2013-CT-00215-COA | 1/10/2013 | Hand Down List
Carlton, Virginia Carter
Walter McComb v. State of Mississippi
2013-CT-00215-COA | 1/10/2013 | Hand Down List
Carlton, Virginia Carter
Walter Robey, Sr. v. Cleveland School District
2012-CA-00755-COA | 4/5/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Walter Robey, Sr. v. Cleveland School District
2012-CA-00755-COA | 4/5/2012 | Hand Down List
Griffis, T. Kenneth, Jr.
Warren D. Friday v. State of Mississippi
2012-CP-01669-COA | 9/21/2012 | Hand Down List
Carlton, Virginia Carter
Warren D. Friday v. State of Mississippi
2012-CP-01669-COA | 9/21/2012 | Hand Down List
Carlton, Virginia Carter
Wayne Marisco v. Allstate Insurance Company
2012-CA-01512-COA | 8/20/2012 | Hand Down List
Irving, Tyree
Wayne Marisco v. Allstate Insurance Company
2012-CA-01512-COA | 8/20/2012 | Hand Down List
Irving, Tyree
Wesley Jaggers v. Janet Jaggers Magruder
2012-CA-00097-COA | 11/3/2011 | Hand Down List
Griffis, T. Kenneth, Jr.
Wesley Jaggers v. Janet Jaggers Magruder
2012-CA-00097-COA | 11/3/2011 | Hand Down List
Griffis, T. Kenneth, Jr.
William Edward Snowden v. State of Mississippi
2012-KA-01524-COA | 8/29/2012 | Hand Down List
Roberts, Larry E.
William Edward Snowden v. State of Mississippi
2012-KA-01524-COA | 8/29/2012 | Hand Down List
Roberts, Larry E.
William Leddell Coggins, Jr. v. Alicia Alvarado Coggins
2012-CA-02030-COA | 11/20/2012 | Hand Down List
Maxwell, James D., II
William Leddell Coggins, Jr. v. Alicia Alvarado Coggins
2012-CA-02030-COA | 11/20/2012 | Hand Down List
Maxwell, James D., II
William Walker v. Williams Transport, LLC
2013-WC-00983-COA |  | Hand Down List
Ishee, David Michael
William Walker v. Williams Transport, LLC
2013-WC-00983-COA |  | Hand Down List
Ishee, David Michael
Willie B. McLeod v. Jeanell McLeod
2012-CA-01677-COA | 10/11/2011 | Hand Down List
Griffis, T. Kenneth, Jr.
Willie B. McLeod v. Jeanell McLeod
2012-CA-01677-COA | 10/11/2011 | Hand Down List
Griffis, T. Kenneth, Jr.
Willie Kinzie v. Belk Department Stores, L.P., Belk, Inc.
2012-CT-01176-SCT | 7/5/2012 | Hand Down List
Carlton, Virginia Carter
Willie Kinzie v. Belk Department Stores, L.P., Belk, Inc.
2012-CT-01176-SCT | 7/5/2012 | Hand Down List
Carlton, Virginia Carter
Willie Kinzie v. Belk Department Stores, L.P., Belk, Inc.
2012-CT-01176-SCT | 7/5/2012 | Hand Down List
Carlton, Virginia Carter
Willie Kinzie v. Belk Department Stores, L.P., Belk, Inc.
2012-CT-01176-SCT | 7/5/2012 | Hand Down List
Carlton, Virginia Carter
Willie Lee Madden, Jr. v. State of Mississippi
2013-CP-00159-COA | 8/3/2012 | Hand Down List
Ishee, David Michael
Willie Lee Madden, Jr. v. State of Mississippi
2013-CP-00159-COA | 8/3/2012 | Hand Down List
Ishee, David Michael
Wilson Krueger, III v. State of Mississippi
2013-KM-00499-COA | 3/6/2013 | Hand Down List
Lee, L. Joseph
Wilson Krueger, III v. State of Mississippi
2013-KM-00499-COA | 3/6/2013 | Hand Down List
Lee, L. Joseph
Wilson Young v. Tommy O'Beirne
2013-CP-00229-COA | 11/17/2011 | Hand Down List
Irving, Tyree
Wilson Young v. Tommy O'Beirne
2013-CP-00229-COA | 11/17/2011 | Hand Down List
Irving, Tyree
Yvonne Lovett v. Delta Regional Medical Center
2013-CT-00410-SCT |  | Hand Down List
Carlton, Virginia Carter
Yvonne Lovett v. Delta Regional Medical Center
2013-CT-00410-SCT |  | Hand Down List
Carlton, Virginia Carter